#########
Reference
#########

Commands
========

.. argparse::
    :module: ivpm.__main__
    :func: get_parser
    :prog: ivpm



YAML File Format
================

.. jsonschema:: ../../src/ivpm/schema/ivpm.json#/defs/package-def

.. jsonschema:: ../../src/ivpm/schema/ivpm.json#/defs/dep-set

.. jsonschema:: ../../src/ivpm/schema/ivpm.json#/defs/package-dep

